@@ -3,7 +3,7 @@ package WebService::JotForm;
 use strict;
 use warnings FATAL => 'all';
 use Moo;
-use JSON::Any;
+use JSON::MaybeXS;
 use LWP::UserAgent;
 use URI::Escape qw(uri_escape);
 use Carp qw(croak);
@@ -16,7 +16,7 @@ Support for create, update, and delete operations are beginning to be added in t
 
 =head1 VERSION
 
-Version 0.019
+Version 0.020
 
 =head1 SYNOPSIS
 	
@@ -53,14 +53,14 @@ More information on tokens is available in the L<JotForm API Documentation|http:
 
 =cut
 
-our $VERSION = '0.019';
+our $VERSION = '0.020';
 
 has 'apiKey'  		=> ( is => 'ro', required => 1);
 has 'apiBase' 		=> ( is => 'ro', default => 'https://api.jotform.com');
 has 'apiVersion'	=> ( is => 'ro', default => 'v1');
 has 'agent'   		=> ( is => 'rw'); # Must act like LWP::UserAgent
 
-my $json = JSON::Any->new;
+my $json = JSON::MaybeXS->new;
 
 sub BUILD {
 	my ($self) = @_;
@@ -565,6 +565,22 @@ sub get_form_webhooks {
 	return $self->_get("form/$form_id/webhooks"); 
 }
 
+=head2 create_form_webhook($form_id, $url)
+
+	$jotform->create_form_webhook($form_id, $url);
+
+	Webhooks can be used to send form submission data as an instant notification.  Add a new webhook that receives submission data for a given form
+
+=cut
+
+sub create_form_webhook {
+	my($self, $form_id, $url) = @_;
+	croak "No form id provided to create_form_webhook" if !$form_id;
+	croak "No url provided to create_form_webhook" if !$url;
+
+	return $self->_post("/form/$form_id/webhooks", { webhookURL => $url });
+}
+
 =head2 get_form_submissions($id)
 
 	$jotform->get_form_submissions($id, $params);
